/*-------------------------------------------------------------------------+
| Copyright 2012 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.databinding;

import static org.eclipse.core.databinding.validation.ValidationStatus.cancel;
import static org.eclipse.core.runtime.Status.OK_STATUS;

import org.eclipse.core.databinding.validation.IValidator;
import org.eclipse.core.runtime.IStatus;

/**
 * Validator for String to Int conversion.
 * 
 * @author hoelzl
 */
public class IntValidator implements IValidator {

	/** Singleton instance. */
	public static final IntValidator INT_VALIDATOR = new IntValidator();

	/** {@inheritDoc} */
	@Override
	public IStatus validate(Object value) {
		if(value instanceof String) {
			try {
				Integer.valueOf((String)value);
				return OK_STATUS;
			} catch(NumberFormatException nfex) {
				// ignore
			}
		}
		return cancel("Illegal int value!");
	}
}
