/*-------------------------------------------------------------------------+
| Copyright 2016 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.utils;

import static org.fortiss.tooling.base.utils.SystemUtils.isLinuxPlatform;
import static org.fortiss.tooling.base.utils.SystemUtils.isMacOSXPlatform;
import static org.fortiss.tooling.base.utils.SystemUtils.isWindowsPlatform;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.graphics.FontData;
import org.eclipse.swt.widgets.Display;

/**
 * Utility class for handling fonts with static singletons for a set of commonly used fonts.
 * 
 * @author hoelzl
 */
public class FontUtils {
	/** Verdana 8pt font. */
	public static FontData VERDANA_8PT = new FontData("Verdana", 8, SWT.NORMAL);
	/** Verdana 10pt font. */
	public static FontData VERDANA_10PT = new FontData("Verdana", 10, SWT.NORMAL);
	/** Verdana 12pt font. */
	public static FontData VERDANA_12PT = new FontData("Verdana", 12, SWT.NORMAL);
	/** Verdana 14pt font. */
	public static FontData VERDANA_14PT = new FontData("Verdana", 14, SWT.NORMAL);
	/** Verdana 14pt font. */
	public static FontData VERDANA_16PT = new FontData("Verdana", 16, SWT.NORMAL);
	/** Verdana 14pt font. */
	public static FontData VERDANA_18PT = new FontData("Verdana", 18, SWT.NORMAL);
	/** "Code" 11pt font. */
	public static FontData CODEFONT_11PT = createCodeFontData(11);

	/** Creates a {@link Font} from the given {@link FontData}, which MUST be disposed after use. */
	public static Font createFont(FontData fontData) {
		return new Font(Display.getCurrent(), fontData);
	}

	/** Returns the {@link FontData} used to represent code (OS specific). */
	private static FontData createCodeFontData(int height) {
		String font = "Courier";
		if(isMacOSXPlatform()) {
			font = "Monaco";
		} else if(isWindowsPlatform()) {
			font = "Consolas";
		} else if(isLinuxPlatform()) {
			font = "Monospace";
		}

		return new FontData(font, height, SWT.NORMAL);
	}
}
