/*-------------------------------------------------------------------------+
| Copyright 2013 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.views;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.Viewer;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation.ESeverity;
import org.fortiss.tooling.kernel.ui.service.IMarkerService;

/**
 * Content provider for the {@link MarkerViewPart}.
 * 
 * @author hoelzl
 */
public class MarkerViewContentProvider implements ITreeContentProvider {
	/** The marker view of this provider. */
	private final MarkerViewPart markerView;

	/** Constructor. */
	public MarkerViewContentProvider(MarkerViewPart markerViewPart) {
		this.markerView = markerViewPart;
	}

	/** {@inheritDoc} */
	@Override
	public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
		// ignore
	}

	/** {@inheritDoc} */
	@Override
	public void dispose() {
		// do nothing
	}

	/** {@inheritDoc} */
	@Override
	public boolean hasChildren(Object element) {
		Object[] objs = getChildren(element);
		return objs != null && objs.length > 0;
	}

	/** {@inheritDoc} */
	@Override
	public Object getParent(Object element) {
		if(element instanceof IConstraintViolation<?>) {
			return ((IConstraintViolation<?>)element).getSeverity();
		}
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public Object[] getElements(Object inputElement) {
		List<ESeverity> result = new ArrayList<ESeverity>();
		for(ESeverity sev : ESeverity.values()) {
			if(sev != ESeverity.lowest() && markerView.getToggleState(sev)) {
				result.add(sev);
			}
		}
		return result.toArray();
	}

	/** {@inheritDoc} */
	@Override
	public Object[] getChildren(Object parentElement) {
		if(parentElement instanceof ESeverity) {
			return IMarkerService.getInstance()
					.getAllViolationsWithSeverity((ESeverity)parentElement).toArray();
		}
		return null;
	}
}
